You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@sling.apache.org by cz...@apache.org on 2016/12/12 12:49:21 UTC

svn commit: r1773785 - in /sling/trunk/bundles/api/src/main/java/org/apache/sling: api/ api/resource/ api/servlets/ spi/resource/provider/

Author: cziegeler
Date: Mon Dec 12 12:49:21 2016
New Revision: 1773785

URL: http://svn.apache.org/viewvc?rev=1773785&view=rev
Log:
Fix javadoc issues

Modified:
    sling/trunk/bundles/api/src/main/java/org/apache/sling/api/SlingConstants.java
    sling/trunk/bundles/api/src/main/java/org/apache/sling/api/resource/ResourceProvider.java
    sling/trunk/bundles/api/src/main/java/org/apache/sling/api/servlets/ServletResolverConstants.java
    sling/trunk/bundles/api/src/main/java/org/apache/sling/spi/resource/provider/QueryLanguageProvider.java
    sling/trunk/bundles/api/src/main/java/org/apache/sling/spi/resource/provider/ResourceProvider.java

Modified: sling/trunk/bundles/api/src/main/java/org/apache/sling/api/SlingConstants.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/api/src/main/java/org/apache/sling/api/SlingConstants.java?rev=1773785&r1=1773784&r2=1773785&view=diff
==============================================================================
--- sling/trunk/bundles/api/src/main/java/org/apache/sling/api/SlingConstants.java (original)
+++ sling/trunk/bundles/api/src/main/java/org/apache/sling/api/SlingConstants.java Mon Dec 12 12:49:21 2016
@@ -266,8 +266,8 @@ public class SlingConstants {
      * The event contains at least the {@link #PROPERTY_PATH}, {@link #PROPERTY_RESOURCE_SUPER_TYPE}
      * and {@link #PROPERTY_RESOURCE_TYPE} properties.
      * @since 2.0.6 (Sling API Bundle 2.0.6)
-     * 
-     * @deprecated Register a {@link ResourceChangeListener} instead
+     *
+     * @deprecated Register a {@link org.apache.sling.api.resource.observation.ResourceChangeListener} instead
      */
     @Deprecated
     public static final String TOPIC_RESOURCE_ADDED = "org/apache/sling/api/resource/Resource/ADDED";
@@ -278,8 +278,8 @@ public class SlingConstants {
      * The event contains at least the {@link #PROPERTY_PATH}. As the resource has already been removed
      * no further information like resource type etc. might be available.
      * @since 2.0.6 (Sling API Bundle 2.0.6)
-     * 
-     * @deprecated Register a {@link ResourceChangeListener} instead
+     *
+     * @deprecated Register a {@link org.apache.sling.api.resource.observation.ResourceChangeListener} instead
      */
     @Deprecated
     public static final String TOPIC_RESOURCE_REMOVED = "org/apache/sling/api/resource/Resource/REMOVED";
@@ -293,8 +293,8 @@ public class SlingConstants {
      * {@link #PROPERTY_REMOVED_ATTRIBUTES}, {@link #PROPERTY_CHANGED_ATTRIBUTES}. All of them are
      * optional.
      * @since 2.0.6 (Sling API Bundle 2.0.6)
-     * 
-     * @deprecated Register a {@link ResourceChangeListener} instead
+     *
+     * @deprecated Register a {@link org.apache.sling.api.resource.observation.ResourceChangeListener} instead
      */
     @Deprecated
     public static final String TOPIC_RESOURCE_CHANGED = "org/apache/sling/api/resource/Resource/CHANGED";

Modified: sling/trunk/bundles/api/src/main/java/org/apache/sling/api/resource/ResourceProvider.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/api/src/main/java/org/apache/sling/api/resource/ResourceProvider.java?rev=1773785&r1=1773784&r2=1773785&view=diff
==============================================================================
--- sling/trunk/bundles/api/src/main/java/org/apache/sling/api/resource/ResourceProvider.java (original)
+++ sling/trunk/bundles/api/src/main/java/org/apache/sling/api/resource/ResourceProvider.java Mon Dec 12 12:49:21 2016
@@ -165,7 +165,7 @@ public interface ResourceProvider {
      *         provider has no children for the given resource.
      * @throws NullPointerException
      *             If {@code parent} is {@code null}.
-     * @throws SlingException
+     * @throws org.apache.sling.api.SlingException
      *             If any error occurs acquiring the child resource iterator.
      */
     @CheckForNull Iterator<Resource> listChildren(@Nonnull Resource parent);

Modified: sling/trunk/bundles/api/src/main/java/org/apache/sling/api/servlets/ServletResolverConstants.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/api/src/main/java/org/apache/sling/api/servlets/ServletResolverConstants.java?rev=1773785&r1=1773784&r2=1773785&view=diff
==============================================================================
--- sling/trunk/bundles/api/src/main/java/org/apache/sling/api/servlets/ServletResolverConstants.java (original)
+++ sling/trunk/bundles/api/src/main/java/org/apache/sling/api/servlets/ServletResolverConstants.java Mon Dec 12 12:49:21 2016
@@ -20,7 +20,7 @@ package org.apache.sling.api.servlets;
 
 /**
  * Service registration properties and common values used for registering a Sling Servlet.
- * 
+ *
  * @see <a href="http://sling.apache.org/documentation/the-sling-engine/servlets.html">Servlets and Scripts</a>
  * @since 2.2.0
  */
@@ -30,18 +30,18 @@ public final class ServletResolverConsta
      * The name of the service registration property of a servlet registered as
      * a service providing the absolute paths under which the servlet is
      * accessible as a resource (value is "sling.servlet.paths").
-     * A relative path is made absolute by prefixing it with the value set through the 
-     * {@link #SLING_SERVLET_PREFIX} property. 
+     * A relative path is made absolute by prefixing it with the value set through the
+     * {@link #SLING_SERVLET_PREFIX} property.
      * <p>
      * The type of this property is a String or String[] (array of strings)
      * denoting the path(s) under which the servlet is registered in the
      * resource tree.
      * <p>
      * Either this property or the {@link #SLING_SERVLET_RESOURCE_TYPES}
-     * property must be set or the servlet is ignored. 
+     * property must be set or the servlet is ignored.
      * If both are set the servlet is registered using both ways.
      * <p>
-     * A servlet using this property might be ignored unless its path is included 
+     * A servlet using this property might be ignored unless its path is included
      * in the Execution Paths {@code servletresolver.paths} configuration setting of the
      * {@code org.apache.sling.servlets.resolver.internal.SlingServletResolver} service.
      */
@@ -51,8 +51,8 @@ public final class ServletResolverConsta
      * The name of the service registration property of a servlet registered as
      * a service containing the resource type(s) supported by the servlet (value
      * is "sling.servlet.resourceTypes").
-     * A relative resource type is made absolute by prefixing it with the value set through the 
-     * {@link #SLING_SERVLET_PREFIX} property. 
+     * A relative resource type is made absolute by prefixing it with the value set through the
+     * {@link #SLING_SERVLET_PREFIX} property.
      * <p>
      * The type of this property is a String or String[] (array of strings)
      * denoting the resource types.
@@ -67,7 +67,7 @@ public final class ServletResolverConsta
      * <p>
      * The name of the service registration property of a servlet registered as
      * a service providing the prefix/index to be used to register this servlet.
-     * It only is applied as prefix to {@link #SLING_SERVLET_PATHS} and 
+     * It only is applied as prefix to {@link #SLING_SERVLET_PATHS} and
      * {@link #SLING_SERVLET_RESOURCE_TYPES} in case they do not start with a "/".
      * </p>
      * <ul>
@@ -109,7 +109,7 @@ public final class ServletResolverConsta
      * <p>
      * The type of this property is a String or String[] (array of strings)
      * denoting the resource types. This property is ignored if the
-     * {@link #SLING_SERVLET_RESOURCE_TYPES} property is not set. 
+     * {@link #SLING_SERVLET_RESOURCE_TYPES} property is not set.
      * Otherwise this property is optional and ignored if not set.
      */
     public static final String SLING_SERVLET_EXTENSIONS = "sling.servlet.extensions";
@@ -121,7 +121,7 @@ public final class ServletResolverConsta
      * <p>
      * The type of this property is a String or String[] (array of strings)
      * denoting the resource types. This property is ignored if the
-     * {@link #SLING_SERVLET_RESOURCE_TYPES} property is not set. 
+     * {@link #SLING_SERVLET_RESOURCE_TYPES} property is not set.
      * Otherwise this property is optional and assumed to be {@code GET} and {@code HEAD} if not set.
      * @see <a href="https://tools.ietf.org/html/rfc7231#section-4.3">HTTP 1.1 Spec Methods</a>
      */
@@ -134,7 +134,7 @@ public final class ServletResolverConsta
      * <code>component.name</code> property or the <code>service.pid</code>
      * is used. If none of the three properties is defined, the Servlet is
      * ignored.
-     * @see ServletConfig#getServletName()
+     * @see javax.servlet.ServletConfig#getServletName()
      */
     public static final String SLING_SERVLET_NAME = "sling.core.servletName";
 

Modified: sling/trunk/bundles/api/src/main/java/org/apache/sling/spi/resource/provider/QueryLanguageProvider.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/api/src/main/java/org/apache/sling/spi/resource/provider/QueryLanguageProvider.java?rev=1773785&r1=1773784&r2=1773785&view=diff
==============================================================================
--- sling/trunk/bundles/api/src/main/java/org/apache/sling/spi/resource/provider/ResourceProvider.java (original)
+++ sling/trunk/bundles/api/src/main/java/org/apache/sling/spi/resource/provider/ResourceProvider.java Mon Dec 12 12:49:21 2016
@@ -25,10 +25,14 @@ import java.util.Map;
 import javax.annotation.CheckForNull;
 import javax.annotation.Nonnull;
 
+import org.apache.sling.api.SlingException;
 import org.apache.sling.api.resource.LoginException;
 import org.apache.sling.api.resource.PersistenceException;
 import org.apache.sling.api.resource.Resource;
+import org.apache.sling.api.resource.ResourceResolver;
+import org.apache.sling.api.resource.ResourceResolverFactory;
 import org.apache.sling.api.resource.ResourceUtil;
+import org.apache.sling.api.resource.SyntheticResource;
 import org.osgi.annotation.versioning.ConsumerType;
 
 /**
@@ -277,7 +281,7 @@ public abstract class ResourceProvider<T
      * privileges assigned to the service provided by the calling bundle.
      * <p>
      * The {@code authenticationInfo} map will in general contain the same
-     * information as provided to the respective {@link ResourceResolver}
+     * information as provided to the respective {@link org.apache.sling.api.resource.ResourceResolver}
      * method. For
      * <p>
      * The provided {@code authenticationInfo} map may be used to provide
--- sling/trunk/bundles/api/src/main/java/org/apache/sling/spi/resource/provider/QueryLanguageProvider.java (original)
+++ sling/trunk/bundles/api/src/main/java/org/apache/sling/spi/resource/provider/QueryLanguageProvider.java Mon Dec 12 12:49:21 2016
@@ -23,6 +23,7 @@ import java.util.Iterator;
 import javax.annotation.Nonnull;
 
 import org.apache.sling.api.resource.Resource;
+import org.apache.sling.api.resource.ResourceResolver;
 import org.apache.sling.api.resource.ValueMap;
 import org.osgi.annotation.versioning.ConsumerType;
 
@@ -62,7 +63,7 @@ public interface QueryLanguageProvider<T
      * @return An <code>Iterator</code> of {@link Resource} objects matching the
      *         query. If no resources match, <code>null</code> might be
      *         returned instead of an empty iterator.
      * @throws QuerySyntaxException If the query is not syntactically correct
      *             according to the query language indicator or if the query
      *             language is not supported as specified in {@link #getSupportedLanguages(ResolveContext)}.
      * @throws org.apache.sling.api.SlingException If an error occurs querying
@@ -92,7 +93,7 @@ public interface QueryLanguageProvider<T
      * @return An <code>Iterator</code> of <code>Map</code> instances providing
      *         access to the query result. If no resources match, <code>null</code>
      *         might be returned instead of an empty iterator.
      * @throws QuerySyntaxException If the query is not syntactically correct
      *             according to the query language indicator or if the query
      *             language is not supported as specified in {@link #getSupportedLanguages(ResolveContext)}.
      * @throws org.apache.sling.api.SlingException If an error occurs querying
@@ -62,7 +63,7 @@ public interface QueryLanguageProvider<T
      *         query. If no resources match, <code>null</code> might be
      *         returned instead of an empty iterator.
-     * @throws QuerySyntaxException If the query is not syntactically correct
+     * @throws org.apache.sling.api.resource.QuerySyntaxException If the query is not syntactically correct
      *             according to the query language indicator or if the query
      *             language is not supported as specified in {@link #getSupportedLanguages(ResolveContext)}.
@@ -92,7 +93,7 @@ public interface QueryLanguageProvider<T
      *         access to the query result. If no resources match, <code>null</code>
      *         might be returned instead of an empty iterator.
-     * @throws QuerySyntaxException If the query is not syntactically correct
+     * @throws org.apache.sling.api.resource.QuerySyntaxException If the query is not syntactically correct
      *             according to the query language indicator or if the query
      *             language is not supported as specified in {@link #getSupportedLanguages(ResolveContext)}.

Modified: sling/trunk/bundles/api/src/main/java/org/apache/sling/spi/resource/provider/ResourceProvider.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/api/src/main/java/org/apache/sling/spi/resource/provider/ResourceProvider.java?rev=1773785&r1=1773784&r2=1773785&view=diff
==============================================================================